@@ -1,5 +1,5 @@
 import matplotlib
-font = {'family': 'arial', 'size': 14}
-matplotlib.rc('font', **font)
+# font = {'family': 'arial', 'size': 14}
+# matplotlib.rc('font', **font)
 # TODO: fix pixel corner coords properly
 matplotlib.rcParams['pcolor.shading'] = 'auto'
