@@ -270,7 +270,7 @@ class CurrentSheet(SourceBaseClass):
         self.current_multiplier = current_multiplier
 
     def __copy__(self):
-        return CurrentLoop(self.x_span, self.radius[0], self.nturns, self.current)
+        return CurrentSheet(self.x_span, self.radius[0], self.nturns, self.current, self.current_multiplier)
 
     @property
     def x_span(self):
@@ -616,6 +616,7 @@ class Task(object):
                 bxs, bys = source.b_field_vec(x_mesh, y_mesh)
                 x_field += bxs
                 y_field += bys
+            # If no vectorized method is present
             except AttributeError:
                 for i in range(x_mesh.shape[0]):
                     for j in range(x_mesh.shape[1]):
